Combining BioServices with external tools
##################################################

.. contents::

This section shows how to use BioServices as an intermediate tool that fetch
data to be used by third-party software/application. 

The external applications used in this section are not part of BioServices therefore we do not provide
instructions for the installation. Reader should refer to the application web
site instead (URLs are provided here below). However, we indicate the way we
installed them. 



.. include:: pymol.rst
.. include:: biopython.rst
.. include:: galaxy.rst



.. .. include:: pyteomics.rst


.. toctree::
   :hidden:

   pymol.rst
   biopython.rst
   galaxy.rst


..   pyteomics.rst






